==> install-blog-v1.6.0.zip: install/en/intro.php <==
<?php
	$type = 'post';
	$published = true;
	$title = 'Congratulations!';
	$description = '';
	$image = '';
	$cats = '';
	$tags = '';
	$date = '2024-06-16';
	$listed = true;
	$pinned = false;
	$front = true;
	include 'lib/default-header.php';
?>

<p>Your blog has been successfully installed! What's next? Here are the next possible steps:</p>

<ul>
	<li>Open the <a href="lib/setup" target="_blank" rel="noopener">Setup</a> program and carry out the initial setup. More about this in the <a href="help#setup" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>

	<li>Personalize your blog! Choose a different style or adjust the colors yourself.
		<ul>
			<li>Use the <a href="lib/setup" target="_blank" rel="noopener">Setup</a> program to select a different <b>user style sheet</b> under "Stylesheets for the live mode". Try <b>cool.css</b>, <b>dark.css</b>, <b>green.css</b> or <b>warm.css</b>.</li>

			<li>Or use your <b>own colors</b>! To do this, select the user style sheet <b>user.css</b> in the <a href="lib/setup" target="_blank" rel="noopener">Setup</a> program under "Stylesheets for the preview mode" (or create your own user style sheet). Then adjust it and activate it. You can find out more about this in the <a href="help#design-user-css" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> document.</li>
		</ul>
	</li>

	<li>Customize the <b>menu!</b> You can link any page in the menu at the top. Delete the example menu items or add your own menu items. More about this in the <a href="help#menu" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file. It is also recommended to delete the "Admin" submenu and save the links listed there as browser bookmarks so that not every visitor to your blog sees these menu items.</li>

	<li>Customize the <b>contact form</b>! Enter an email address to which the messages sent via it should be emailed. To do this, go to the <a href="lib/editor" target="_blank" rel="noopener">Editor</a>, open the "Contact" file and adjust it according to the instructions in the <a href="help#contact" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>

	<li>Customize the <b>sidebar</b>! On the right (or left, depending on the style) in the sidebar (or below this post on narrow displays) you will see some elements, the so-called "<b>widgets</b>". Choose which widgets should be listed there and in which order, or create your own widgets. You can find out how to do this - guess where? - in the <a href="help#widgets" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>

	<li>Would you like to have a static page rather than a post overview as your <b>homepage</b>? That is also possible: See the <a href="help#homepage" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file...</li>

	<li>Set this small <b>introductory post</b> to "invisible" so that it is no longer listed in the post overview on the homepage. To do this, go to the <a href="lib/editor" target="_blank" rel="noopener">Editor</a>, open this post, click on "Edit" at the top, remove the check mark next to "Published" and click on "Save".</li>

	<li>Get started and create your <b>first post</b>! To do this, open the <a href="lib/editor" target="_blank" rel="noopener">Editor</a>, click on "New" at the top, select a template or "Blank Page" and write something. Here, too, please refer to the <a href="help#user-controls" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>
</ul>

<p>One final note: All of the links mentioned here (<a href="lib/editor" target="_blank" rel="noopener">Editor</a>, <a href="lib/setup" target="_blank" rel="noopener">Setup</a>, <a href="help" target="_blank" rel="noopener">Help</a>) and this short <a href="intro">introductory text</a> can also be found in the menu under Admin (unless you have removed this submenu).</p>

<?php include 'lib/default-footer.php'; ?>

==> install-blog-v1.7.0.zip: install/en/intro.php <==
<?php
	$type = 'post';
	$published = true;
	$title = 'Congratulations!';
	$description = '';
	$image = '';
	$cats = '';
	$tags = '';
	$date = '2024-06-16';
	$listed = true;
	$pinned = false;
	$front = true;
	include 'lib/default-header.php';
?>

<p>Your blog has been successfully installed! What's next? Here are the next possible steps:</p>

<ul>
	<li>Open the <a href="lib/setup" target="_blank" rel="noopener">Setup</a> program and carry out the initial setup. More about this in the <a href="help#setup" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>

	<li>Personalize your blog! Choose a different style or adjust the colors yourself.
		<ul>
			<li>Use the <a href="lib/setup" target="_blank" rel="noopener">Setup</a> program to select a different <b>user style sheet</b> under "Stylesheets for the live mode". Try <b>cool.css</b>, <b>dark.css</b>, <b>green.css</b> or <b>warm.css</b>.</li>

			<li>Or use your <b>own colors</b>! To do this, select the user style sheet <b>user.css</b> in the <a href="lib/setup" target="_blank" rel="noopener">Setup</a> program under "Stylesheets for the preview mode" (or create your own user style sheet). Then adjust it and activate it. You can find out more about this in the <a href="help#design-user-css" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> document.</li>
		</ul>
	</li>

	<li>Customize the <b>menu!</b> You can link any page in the menu at the top. Delete the example menu items or add your own menu items. More about this in the <a href="help#menu" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file. It is also recommended to delete the "Admin" submenu and save the links listed there as browser bookmarks so that not every visitor to your blog sees these menu items.</li>

	<li>Customize the <b>contact form</b>! Enter an email address to which the messages sent via it should be emailed. To do this, go to the <a href="lib/editor" target="_blank" rel="noopener">Editor</a>, open the "Contact" file and adjust it according to the instructions in the <a href="help#contact" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>

	<li>Set up a <b>guestbook</b> where visitors to your blog can leave publicly readable greetings and comments. You'll find all the necessary instructions in the <a href="help#guestbook" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file. An example guestbook is already linked under "Contact" in the menu at the top. If you don't need a guestbook, remove this menu item.</li>

	<li>Customize the <b>sidebar</b>! On the right (or left, depending on the style) in the sidebar (or below this post on narrow displays) you will see some elements, the so-called "<b>widgets</b>". Choose which widgets should be listed there and in which order, or create your own widgets. You can find out how to do this - guess where? - in the <a href="help#widgets" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>

	<li>Would you like to have a static page rather than a post overview as your <b>homepage</b>? That is also possible: See the <a href="help#homepage" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file...</li>

	<li>Set this small <b>introductory post</b> to "invisible" so that it is no longer listed in the post overview on the homepage. To do this, go to the <a href="lib/editor" target="_blank" rel="noopener">Editor</a>, open this post, click on "Edit" at the top, remove the check mark next to "Published" and click on "Save".</li>

	<li>Get started and create your <b>first post</b>! To do this, open the <a href="lib/editor" target="_blank" rel="noopener">Editor</a>, click on "New" at the top, select a template or "Blank Page" and write something. Here, too, please refer to the <a href="help#user-controls" target="_blank" rel="noopener" x-data-translate-from="de">Help</a> file.</li>
</ul>

<p>One final note: All of the links mentioned here (<a href="lib/editor" target="_blank" rel="noopener">Editor</a>, <a href="lib/setup" target="_blank" rel="noopener">Setup</a>, <a href="help" target="_blank" rel="noopener">Help</a>) and this short <a href="intro">introductory text</a> can also be found in the menu under Admin (unless you have removed this submenu).</p>

<?php include 'lib/default-footer.php'; ?>
